==> webpdf-wsclient-2.0.0-sources.jar: net/webpdf/wsclient/schema/extraction/info/ObjectFactory.java <==

package net.webpdf.wsclient.schema.extraction.info;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.webpdf.wsclient.schema.extraction.info package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.webpdf.wsclient.schema.extraction.info
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link HeaderFooterType }
     * 
     */
    public HeaderFooterType createHeaderFooterType() {
        return new HeaderFooterType();
    }

    /**
     * Create an instance of {@link BackgroundContentType }
     * 
     */
    public BackgroundContentType createBackgroundContentType() {
        return new BackgroundContentType();
    }

    /**
     * Create an instance of {@link DocumentType }
     * 
     */
    public DocumentType createDocumentType() {
        return new DocumentType();
    }

    /**
     * Create an instance of {@link DocumentType.Pages }
     * 
     */
    public DocumentType.Pages createDocumentTypePages() {
        return new DocumentType.Pages();
    }

    /**
     * Create an instance of {@link InformationType }
     * 
     */
    public InformationType createInformationType() {
        return new InformationType();
    }

    /**
     * Create an instance of {@link DescriptionType }
     * 
     */
    public DescriptionType createDescriptionType() {
        return new DescriptionType();
    }

    /**
     * Create an instance of {@link SecurityType }
     * 
     */
    public SecurityType createSecurityType() {
        return new SecurityType();
    }

    /**
     * Create an instance of {@link AttachmentType }
     * 
     */
    public AttachmentType createAttachmentType() {
        return new AttachmentType();
    }

    /**
     * Create an instance of {@link PageType }
     * 
     */
    public PageType createPageType() {
        return new PageType();
    }

    /**
     * Create an instance of {@link PdfaType }
     * 
     */
    public PdfaType createPdfaType() {
        return new PdfaType();
    }

    /**
     * Create an instance of {@link FieldType }
     * 
     */
    public FieldType createFieldType() {
        return new FieldType();
    }

    /**
     * Create an instance of {@link SignatureType }
     * 
     */
    public SignatureType createSignatureType() {
        return new SignatureType();
    }

    /**
     * Create an instance of {@link AuthorType }
     * 
     */
    public AuthorType createAuthorType() {
        return new AuthorType();
    }

    /**
     * Create an instance of {@link KeywordType }
     * 
     */
    public KeywordType createKeywordType() {
        return new KeywordType();
    }

    /**
     * Create an instance of {@link PasswordType }
     * 
     */
    public PasswordType createPasswordType() {
        return new PasswordType();
    }

    /**
     * Create an instance of {@link AnnotationType }
     * 
     */
    public AnnotationType createAnnotationType() {
        return new AnnotationType();
    }

    /**
     * Create an instance of {@link MarkupType }
     * 
     */
    public MarkupType createMarkupType() {
        return new MarkupType();
    }

    /**
     * Create an instance of {@link PopupType }
     * 
     */
    public PopupType createPopupType() {
        return new PopupType();
    }

    /**
     * Create an instance of {@link RectangleType }
     * 
     */
    public RectangleType createRectangleType() {
        return new RectangleType();
    }

    /**
     * Create an instance of {@link PointType }
     * 
     */
    public PointType createPointType() {
        return new PointType();
    }

    /**
     * Create an instance of {@link AppearanceType }
     * 
     */
    public AppearanceType createAppearanceType() {
        return new AppearanceType();
    }

    /**
     * Create an instance of {@link PositionsType }
     * 
     */
    public PositionsType createPositionsType() {
        return new PositionsType();
    }

    /**
     * Create an instance of {@link LineType }
     * 
     */
    public LineType createLineType() {
        return new LineType();
    }

    /**
     * Create an instance of {@link BorderStyle }
     * 
     */
    public BorderStyle createBorderStyle() {
        return new BorderStyle();
    }

    /**
     * Create an instance of {@link ColorType }
     * 
     */
    public ColorType createColorType() {
        return new ColorType();
    }

    /**
     * Create an instance of {@link BoxesType }
     * 
     */
    public BoxesType createBoxesType() {
        return new BoxesType();
    }

    /**
     * Create an instance of {@link FontType }
     * 
     */
    public FontType createFontType() {
        return new FontType();
    }

    /**
     * Create an instance of {@link MarginType }
     * 
     */
    public MarginType createMarginType() {
        return new MarginType();
    }

    /**
     * Create an instance of {@link TransitionType }
     * 
     */
    public TransitionType createTransitionType() {
        return new TransitionType();
    }

    /**
     * Create an instance of {@link ImageType }
     * 
     */
    public ImageType createImageType() {
        return new ImageType();
    }

    /**
     * Create an instance of {@link FormValueStyle }
     * 
     */
    public FormValueStyle createFormValueStyle() {
        return new FormValueStyle();
    }

    /**
     * Create an instance of {@link FolderType }
     * 
     */
    public FolderType createFolderType() {
        return new FolderType();
    }

    /**
     * Create an instance of {@link HeaderFooterType.Header }
     * 
     */
    public HeaderFooterType.Header createHeaderFooterTypeHeader() {
        return new HeaderFooterType.Header();
    }

    /**
     * Create an instance of {@link HeaderFooterType.Footer }
     * 
     */
    public HeaderFooterType.Footer createHeaderFooterTypeFooter() {
        return new HeaderFooterType.Footer();
    }

    /**
     * Create an instance of {@link BackgroundContentType.PieceInfo }
     * 
     */
    public BackgroundContentType.PieceInfo createBackgroundContentTypePieceInfo() {
        return new BackgroundContentType.PieceInfo();
    }

    /**
     * Create an instance of {@link DocumentType.Attachments }
     * 
     */
    public DocumentType.Attachments createDocumentTypeAttachments() {
        return new DocumentType.Attachments();
    }

    /**
     * Create an instance of {@link DocumentType.Form }
     * 
     */
    public DocumentType.Form createDocumentTypeForm() {
        return new DocumentType.Form();
    }

    /**
     * Create an instance of {@link DocumentType.Annotations }
     * 
     */
    public DocumentType.Annotations createDocumentTypeAnnotations() {
        return new DocumentType.Annotations();
    }

    /**
     * Create an instance of {@link DocumentType.Signatures }
     * 
     */
    public DocumentType.Signatures createDocumentTypeSignatures() {
        return new DocumentType.Signatures();
    }

    /**
     * Create an instance of {@link DocumentType.Backgrounds }
     * 
     */
    public DocumentType.Backgrounds createDocumentTypeBackgrounds() {
        return new DocumentType.Backgrounds();
    }

    /**
     * Create an instance of {@link DocumentType.HeadersFooters }
     * 
     */
    public DocumentType.HeadersFooters createDocumentTypeHeadersFooters() {
        return new DocumentType.HeadersFooters();
    }

    /**
     * Create an instance of {@link DocumentType.Transitions }
     * 
     */
    public DocumentType.Transitions createDocumentTypeTransitions() {
        return new DocumentType.Transitions();
    }

    /**
     * Create an instance of {@link DocumentType.Images }
     * 
     */
    public DocumentType.Images createDocumentTypeImages() {
        return new DocumentType.Images();
    }

    /**
     * Create an instance of {@link DocumentType.Folders }
     * 
     */
    public DocumentType.Folders createDocumentTypeFolders() {
        return new DocumentType.Folders();
    }

    /**
     * Create an instance of {@link DocumentType.Pages.Page }
     * 
     */
    public DocumentType.Pages.Page createDocumentTypePagesPage() {
        return new DocumentType.Pages.Page();
    }

}

==> webpdf-wsclient-2.0.3-sources.jar: net/webpdf/wsclient/schema/extraction/info/ObjectFactory.java <==

package net.webpdf.wsclient.schema.extraction.info;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.webpdf.wsclient.schema.extraction.info package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.webpdf.wsclient.schema.extraction.info
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link HeaderFooterType }
     * 
     */
    public HeaderFooterType createHeaderFooterType() {
        return new HeaderFooterType();
    }

    /**
     * Create an instance of {@link BackgroundContentType }
     * 
     */
    public BackgroundContentType createBackgroundContentType() {
        return new BackgroundContentType();
    }

    /**
     * Create an instance of {@link DocumentType }
     * 
     */
    public DocumentType createDocumentType() {
        return new DocumentType();
    }

    /**
     * Create an instance of {@link DocumentType.Pages }
     * 
     */
    public DocumentType.Pages createDocumentTypePages() {
        return new DocumentType.Pages();
    }

    /**
     * Create an instance of {@link InformationType }
     * 
     */
    public InformationType createInformationType() {
        return new InformationType();
    }

    /**
     * Create an instance of {@link DescriptionType }
     * 
     */
    public DescriptionType createDescriptionType() {
        return new DescriptionType();
    }

    /**
     * Create an instance of {@link SecurityType }
     * 
     */
    public SecurityType createSecurityType() {
        return new SecurityType();
    }

    /**
     * Create an instance of {@link AttachmentType }
     * 
     */
    public AttachmentType createAttachmentType() {
        return new AttachmentType();
    }

    /**
     * Create an instance of {@link PageType }
     * 
     */
    public PageType createPageType() {
        return new PageType();
    }

    /**
     * Create an instance of {@link PdfaType }
     * 
     */
    public PdfaType createPdfaType() {
        return new PdfaType();
    }

    /**
     * Create an instance of {@link FieldType }
     * 
     */
    public FieldType createFieldType() {
        return new FieldType();
    }

    /**
     * Create an instance of {@link SignatureType }
     * 
     */
    public SignatureType createSignatureType() {
        return new SignatureType();
    }

    /**
     * Create an instance of {@link AuthorType }
     * 
     */
    public AuthorType createAuthorType() {
        return new AuthorType();
    }

    /**
     * Create an instance of {@link KeywordType }
     * 
     */
    public KeywordType createKeywordType() {
        return new KeywordType();
    }

    /**
     * Create an instance of {@link CustomDescriptionType }
     * 
     */
    public CustomDescriptionType createCustomDescriptionType() {
        return new CustomDescriptionType();
    }

    /**
     * Create an instance of {@link PasswordType }
     * 
     */
    public PasswordType createPasswordType() {
        return new PasswordType();
    }

    /**
     * Create an instance of {@link AnnotationType }
     * 
     */
    public AnnotationType createAnnotationType() {
        return new AnnotationType();
    }

    /**
     * Create an instance of {@link MarkupType }
     * 
     */
    public MarkupType createMarkupType() {
        return new MarkupType();
    }

    /**
     * Create an instance of {@link PopupType }
     * 
     */
    public PopupType createPopupType() {
        return new PopupType();
    }

    /**
     * Create an instance of {@link RectangleType }
     * 
     */
    public RectangleType createRectangleType() {
        return new RectangleType();
    }

    /**
     * Create an instance of {@link PointType }
     * 
     */
    public PointType createPointType() {
        return new PointType();
    }

    /**
     * Create an instance of {@link AppearanceType }
     * 
     */
    public AppearanceType createAppearanceType() {
        return new AppearanceType();
    }

    /**
     * Create an instance of {@link PositionsType }
     * 
     */
    public PositionsType createPositionsType() {
        return new PositionsType();
    }

    /**
     * Create an instance of {@link LineType }
     * 
     */
    public LineType createLineType() {
        return new LineType();
    }

    /**
     * Create an instance of {@link BorderStyle }
     * 
     */
    public BorderStyle createBorderStyle() {
        return new BorderStyle();
    }

    /**
     * Create an instance of {@link ColorType }
     * 
     */
    public ColorType createColorType() {
        return new ColorType();
    }

    /**
     * Create an instance of {@link BoxesType }
     * 
     */
    public BoxesType createBoxesType() {
        return new BoxesType();
    }

    /**
     * Create an instance of {@link FontType }
     * 
     */
    public FontType createFontType() {
        return new FontType();
    }

    /**
     * Create an instance of {@link MarginType }
     * 
     */
    public MarginType createMarginType() {
        return new MarginType();
    }

    /**
     * Create an instance of {@link TransitionType }
     * 
     */
    public TransitionType createTransitionType() {
        return new TransitionType();
    }

    /**
     * Create an instance of {@link ImageType }
     * 
     */
    public ImageType createImageType() {
        return new ImageType();
    }

    /**
     * Create an instance of {@link FormValueStyle }
     * 
     */
    public FormValueStyle createFormValueStyle() {
        return new FormValueStyle();
    }

    /**
     * Create an instance of {@link FolderType }
     * 
     */
    public FolderType createFolderType() {
        return new FolderType();
    }

    /**
     * Create an instance of {@link ViewerPreferencesType }
     * 
     */
    public ViewerPreferencesType createViewerPreferencesType() {
        return new ViewerPreferencesType();
    }

    /**
     * Create an instance of {@link HeaderFooterType.Header }
     * 
     */
    public HeaderFooterType.Header createHeaderFooterTypeHeader() {
        return new HeaderFooterType.Header();
    }

    /**
     * Create an instance of {@link HeaderFooterType.Footer }
     * 
     */
    public HeaderFooterType.Footer createHeaderFooterTypeFooter() {
        return new HeaderFooterType.Footer();
    }

    /**
     * Create an instance of {@link BackgroundContentType.PieceInfo }
     * 
     */
    public BackgroundContentType.PieceInfo createBackgroundContentTypePieceInfo() {
        return new BackgroundContentType.PieceInfo();
    }

    /**
     * Create an instance of {@link DocumentType.Attachments }
     * 
     */
    public DocumentType.Attachments createDocumentTypeAttachments() {
        return new DocumentType.Attachments();
    }

    /**
     * Create an instance of {@link DocumentType.Form }
     * 
     */
    public DocumentType.Form createDocumentTypeForm() {
        return new DocumentType.Form();
    }

    /**
     * Create an instance of {@link DocumentType.Annotations }
     * 
     */
    public DocumentType.Annotations createDocumentTypeAnnotations() {
        return new DocumentType.Annotations();
    }

    /**
     * Create an instance of {@link DocumentType.Signatures }
     * 
     */
    public DocumentType.Signatures createDocumentTypeSignatures() {
        return new DocumentType.Signatures();
    }

    /**
     * Create an instance of {@link DocumentType.Backgrounds }
     * 
     */
    public DocumentType.Backgrounds createDocumentTypeBackgrounds() {
        return new DocumentType.Backgrounds();
    }

    /**
     * Create an instance of {@link DocumentType.HeadersFooters }
     * 
     */
    public DocumentType.HeadersFooters createDocumentTypeHeadersFooters() {
        return new DocumentType.HeadersFooters();
    }

    /**
     * Create an instance of {@link DocumentType.Transitions }
     * 
     */
    public DocumentType.Transitions createDocumentTypeTransitions() {
        return new DocumentType.Transitions();
    }

    /**
     * Create an instance of {@link DocumentType.Images }
     * 
     */
    public DocumentType.Images createDocumentTypeImages() {
        return new DocumentType.Images();
    }

    /**
     * Create an instance of {@link DocumentType.Folders }
     * 
     */
    public DocumentType.Folders createDocumentTypeFolders() {
        return new DocumentType.Folders();
    }

    /**
     * Create an instance of {@link DocumentType.Pages.Page }
     * 
     */
    public DocumentType.Pages.Page createDocumentTypePagesPage() {
        return new DocumentType.Pages.Page();
    }

}
